@@ -18,6 +18,7 @@ from ..core import urlopen, get_remote_file
 
 from pathlib import Path
 from urllib.parse import urlparse
+from typing import Optional
 
 # URI types
 URI_BYTES = 1
@@ -185,7 +186,7 @@ EXAMPLE_IMAGES = {
 
 
 class Request(object):
-    """Request(uri, mode, **kwargs)
+    """ImageResource handling utility.
 
     Represents a request for reading or saving an image resource. This
     object wraps information to that request and acts as an interface
@@ -200,7 +201,7 @@ class Request(object):
     information between different formats and between a format and
     associated reader/writer.
 
-    parameters
+    Parameters
     ----------
     uri : {str, bytes, file}
         The resource to load the image from.
@@ -209,15 +210,17 @@ class Request(object):
         request. The second character is used to indicate the kind of data:
         "i" for an image, "I" for multiple images, "v" for a volume,
         "V" for multiple volumes, "?" for don't care.
+
     """
 
-    def __init__(self, uri, mode, **kwargs):
+    def __init__(self, uri, mode, *, format_hint: str = None, **kwargs):
 
         # General
         self.raw_uri = uri
         self._uri_type = None
         self._filename = None
         self._extension = None
+        self._format_hint = None
         self._kwargs = kwargs
         self._result = None  # Some write actions may have a result
 
@@ -253,6 +256,8 @@ class Request(object):
             ext = Path(path).suffix.lower()
             self._extension = ext if ext != "" else None
 
+        self.format_hint = format_hint
+
     def _parse_uri(self, uri):
         """Try to figure our what we were given"""
         is_read_request = self.mode.io_mode is IOMode.read
@@ -389,7 +394,10 @@ class Request(object):
 
     @property
     def filename(self):
-        """The uri for which reading/saving was requested. This
+        """Name of the ImageResource.
+
+
+        The uri for which reading/saving was requested. This
         can be a filename, an http address, or other resource
         identifier. Do not rely on the filename to obtain the data,
         but use ``get_file()`` or ``get_local_filename()`` instead.
@@ -397,13 +405,23 @@ class Request(object):
         return self._filename
 
     @property
-    def extension(self):
+    def extension(self) -> str:
         """The (lowercase) extension of the requested filename.
         Suffixes in url's are stripped. Can be None if the request is
         not based on a filename.
         """
         return self._extension
 
+    @property
+    def format_hint(self) -> Optional[str]:
+        return self._format_hint
+
+    @format_hint.setter
+    def format_hint(self, format: str) -> None:
+        self._format_hint = format
+        if self._extension is None:
+            self._extension = format
+
     @property
     def mode(self):
         """The mode of the request. The first character is "r" or "w",
@@ -488,7 +506,9 @@ class Request(object):
             return self._filename
         else:
             # Get filename
-            if self._uri_type in (URI_HTTP, URI_FTP):
+            if self.format_hint is not None:
+                ext = self.format_hint
+            elif self._uri_type in (URI_HTTP, URI_FTP):
                 ext = os.path.splitext(self._filename.split("?")[0])[1]
             else:
                 ext = os.path.splitext(self._filename)[1]
