@@ -266,6 +266,7 @@ class PyAVPlugin(PluginV3):
                     msg = f"PyAV does not support `{request.raw_uri}`"
                 raise InitializationError(msg) from None
         else:
+            self.frames_written = 0
             file_handle = self.request.get_file()
             filename = getattr(file_handle, "name", None)
             extension = self.request.extension or self.request.format_hint
@@ -615,7 +616,8 @@ class PyAVPlugin(PluginV3):
         ]
 
         for img in ndimage:
-            frame.pts = self._video_stream.frames
+            frame.pts = self.frames_written
+            self.frames_written += 1
             # manual packing of ndarray into frame
             # (this should live in pyAV, but it doesn't support many formats
             # and PRs there are slow)
@@ -629,9 +631,12 @@ class PyAVPlugin(PluginV3):
                     )
                     plane_array[...] = img[idx]
             else:
-                n_channels = len(pixel_format.components)
-                plane = frame.planes[0]
+                if in_pixel_format.startswith("bayer_"):
+                    n_channels = 1
+                else:
+                    n_channels = len(pixel_format.components)
 
+                plane = frame.planes[0]
                 plane_shape = (plane.height, plane.width)
                 plane_strides = (plane.line_size, n_channels * img_dtype.itemsize)
                 if n_channels > 1:
@@ -655,7 +660,6 @@ class PyAVPlugin(PluginV3):
                 self._container.mux(packet)
 
         for out_frame in ffmpeg_filter:
-            out_frame.pts = self._video_stream.frames
             for packet in stream.encode(out_frame):
                 self._container.mux(packet)
 
