@@ -175,6 +175,12 @@ import warnings
 try:
     import tifffile as _tifffile
 except ImportError:
+    warnings.warn(
+        "ImageIO's vendored tifffile backend is deprecated and will be"
+        " removed in ImageIO v3. Install the tifffile directly:"
+        " `pip install imageio[tifffile]`",
+        DeprecationWarning,
+    )
     from . import _tifffile
 
 
@@ -486,14 +492,17 @@ class TiffFormat(Format):
         def _open(self, bigtiff=None, byteorder=None, software=None):
             try:
                 self._tf = _tifffile.TiffWriter(
-                    self.request.get_file(), bigtiff, byteorder, software=software
+                    self.request.get_file(),
+                    bigtiff=bigtiff,
+                    byteorder=byteorder,
+                    software=software,
                 )
                 self._software = None
             except TypeError:
                 # In tifffile >= 0.15, the `software` arg is passed to
                 # TiffWriter.save
                 self._tf = _tifffile.TiffWriter(
-                    self.request.get_file(), bigtiff, byteorder
+                    self.request.get_file(), bigtiff=bigtiff, byteorder=byteorder
                 )
                 self._software = software
 
